==> tiferet-1.1.13.tar.gz: tiferet-1.1.13/tiferet/data/app.py <==
"""Tiferet App Data Transfer Objects"""

# *** imports

# ** app
from ..models import (
    AppAttribute,
    AppInterface,
    StringType,
    DictType,
    ModelType,
)
from ..contracts import (
    AppAttributeContract,
    AppInterfaceContract
)
from .settings import (
    DataObject,
    DEFAULT_MODULE_PATH,
    DEFAULT_CLASS_NAME
)

# *** data

# ** data: app_attribute_yaml_data
class AppAttributeYamlData(AppAttribute, DataObject):
    '''
    A YAML data representation of an app dependency attribute object.
    '''

    # * attribute: attribute_id
    attribute_id = StringType(
        metadata=dict(
            description='The attribute id for the application dependency that is not required for assembly.'
        ),
    )

    # * attribute: parameters
    parameters = DictType(
        StringType,
        default={},
        serialized_name='params',
        deserialize_from=['params', 'parameters'],
        metadata=dict(
            description='The parameters for the application dependency that are not required for assembly.'
        ),
    )

    class Options():
        '''
        The options for the app dependency data.
        '''

        serialize_when_none = False
        roles = {
            'to_model': DataObject.deny('parameters', 'attribute_id'),
            'to_data.yaml': DataObject.deny('attribute_id')
        }

    # * method: map
    def map(self, attribute_id: str, **kwargs) -> AppAttributeContract:
        '''
        Maps the app dependency data to an app dependency object.

        :param attribute_id: The id for the app dependency attribute.
        :type attribute_id: str
        :param kwargs: Additional keyword arguments.
        :type kwargs: dict
        :return: A new app attribute dependency contract.
        :rtype: AppAttributeContract
        '''

        # Map to the app dependency object.
        return super().map(
            AppAttribute,
            attribute_id=attribute_id,
            parameters=self.parameters,
            **self.to_primitive('to_model'),
            **kwargs
        )

# ** data: app_interface_yaml_data
class AppInterfaceYamlData(AppInterface, DataObject):
    '''
    A data representation of an app interface settings object.
    '''

    class Options():
        '''
        The options for the app interface data.
        '''
        serialize_when_none = False
        roles = {
            'to_model': DataObject.deny('attributes', 'constants', 'module_path', 'class_name'),
            'to_data.yaml': DataObject.deny('id')
        }

    # * attribute: module_path
    module_path = StringType(
        default=DEFAULT_MODULE_PATH,
        serialized_name='module',
        deserialize_from=['module_path', 'module'],
        metadata=dict(
            description='The app context module path for the app settings.'
        ),
    )

    # * attribute: class_name
    class_name = StringType(
        default=DEFAULT_CLASS_NAME,
        serialized_name='class',
        deserialize_from=['class_name', 'class'],
        metadata=dict(
            description='The class name for the app context.'
        ),
    )

    # * attribute: attributes
    attributes = DictType(
        ModelType(AppAttributeYamlData),
        default={},
        serialized_name='attrs',
        deserialize_from=['attrs', 'attributes'],
        metadata=dict(
            description='The app instance attributes.'
        ),
    )

    # * attribute: constants
    constants = DictType(
        StringType,
        default={},
        serialized_name='const',
        deserialize_from=['constants', 'const'],
        metadata=dict(
            description='The constants for the app settings.'
        ),
    )

    # * method: map
    def map(self, **kwargs) -> AppInterfaceContract:
        '''
        Maps the app interface data to an app interface contract.

        :param role: The role for the mapping.
        :type role: str
        :param kwargs: Additional keyword arguments.
        :type kwargs: dict
        :return: A new app interface contract.
        :rtype: AppInterfaceContract
        '''

        # Map the app interface data.
        return super().map(
            AppInterface,
            module_path=self.module_path,
            class_name=self.class_name,
            attributes=[attr.map(attribute_id=attr_id) for attr_id, attr in self.attributes.items()],
            constants=self.constants,
            **self.to_primitive('to_model'),
            **kwargs
        )

==> tiferet-1.2.2.tar.gz: tiferet-1.2.2/tiferet/data/app.py <==
"""Tiferet App Data Objects"""

# *** imports

# ** app
from ..models import (
    AppAttribute,
    AppInterface,
    StringType,
    DictType,
    ModelType,
)
from ..contracts import (
    AppAttributeContract,
    AppInterfaceContract
)
from .settings import (
    DataObject,
    DEFAULT_MODULE_PATH,
    DEFAULT_CLASS_NAME
)

# *** data

# ** data: app_attribute_config_data
class AppAttributeConfigData(AppAttribute, DataObject):
    '''
    A YAML data representation of an app dependency attribute object.
    '''

    # * attribute: attribute_id
    attribute_id = StringType(
        metadata=dict(
            description='The attribute id for the application dependency that is not required for assembly.'
        ),
    )

    # * attribute: parameters
    parameters = DictType(
        StringType,
        default={},
        serialized_name='params',
        deserialize_from=['params', 'parameters'],
        metadata=dict(
            description='The parameters for the application dependency that are not required for assembly.'
        ),
    )

    class Options():
        '''
        The options for the app dependency data.
        '''

        serialize_when_none = False
        roles = {
            'to_model': DataObject.deny('parameters', 'attribute_id'),
            'to_data.yaml': DataObject.deny('attribute_id')
        }

    # * method: map
    def map(self, attribute_id: str, **kwargs) -> AppAttributeContract:
        '''
        Maps the app dependency data to an app dependency object.

        :param attribute_id: The id for the app dependency attribute.
        :type attribute_id: str
        :param kwargs: Additional keyword arguments.
        :type kwargs: dict
        :return: A new app attribute dependency contract.
        :rtype: AppAttributeContract
        '''

        # Map to the app dependency object.
        return super().map(
            AppAttribute,
            attribute_id=attribute_id,
            parameters=self.parameters,
            **self.to_primitive('to_model'),
            **kwargs
        )

# ** data: app_interface_config_data
class AppInterfaceConfigData(AppInterface, DataObject):
    '''
    A data representation of an app interface settings object.
    '''

    class Options():
        '''
        The options for the app interface data.
        '''
        serialize_when_none = False
        roles = {
            'to_model': DataObject.deny('attributes', 'constants', 'module_path', 'class_name'),
            'to_data.yaml': DataObject.deny('id')
        }

    # * attribute: module_path
    module_path = StringType(
        default=DEFAULT_MODULE_PATH,
        serialized_name='module',
        deserialize_from=['module_path', 'module'],
        metadata=dict(
            description='The app context module path for the app settings.'
        ),
    )

    # * attribute: class_name
    class_name = StringType(
        default=DEFAULT_CLASS_NAME,
        serialized_name='class',
        deserialize_from=['class_name', 'class'],
        metadata=dict(
            description='The class name for the app context.'
        ),
    )

    # * attribute: attributes
    attributes = DictType(
        ModelType(AppAttributeConfigData),
        default={},
        serialized_name='attrs',
        deserialize_from=['attrs', 'attributes'],
        metadata=dict(
            description='The app instance attributes.'
        ),
    )

    # * attribute: constants
    constants = DictType(
        StringType,
        default={},
        serialized_name='const',
        deserialize_from=['constants', 'const'],
        metadata=dict(
            description='The constants for the app settings.'
        ),
    )

    # * method: map
    def map(self, **kwargs) -> AppInterfaceContract:
        '''
        Maps the app interface data to an app interface contract.

        :param role: The role for the mapping.
        :type role: str
        :param kwargs: Additional keyword arguments.
        :type kwargs: dict
        :return: A new app interface contract.
        :rtype: AppInterfaceContract
        '''

        # Map the app interface data.
        return super().map(
            AppInterface,
            module_path=self.module_path,
            class_name=self.class_name,
            attributes=[attr.map(attribute_id=attr_id) for attr_id, attr in self.attributes.items()],
            constants=self.constants,
            **self.to_primitive('to_model'),
            **kwargs
        )

    # * method: from_model
    @staticmethod
    def from_model(app_interface: AppInterface, **kwargs) -> 'AppInterfaceConfigData':
        '''
        Creates an AppInterfaceConfigData object from an AppInterfaceContract object.
        :param app_interface: The app interface contract.
        :type app_interface: AppInterfaceContract
        :param kwargs: Additional keyword arguments.
        :type kwargs: dict
        :return: A new AppInterfaceConfigData object.
        :rtype: AppInterfaceConfigData
        '''

        # Create a new AppInterfaceConfigData object from the model.
        return DataObject.from_model(
            AppInterfaceConfigData,
            attributes={attr.attribute_id: DataObject.from_model(AppAttributeConfigData, attr) for attr in app_interface.attributes},
            **kwargs
        )
